package com.jiuqi.util;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/CustomIniFile.class */
public abstract class CustomIniFile implements IniFile {
    @Override // com.jiuqi.util.IniFile
    public void writeInteger(String section, String ident, Integer value) {
        writeString(section, ident, value == null ? JqLib.SQL_FALSE : value.toString());
    }

    @Override // com.jiuqi.util.IniFile
    public void writeint(String section, String ident, int value) {
        writeString(section, ident, Integer.toString(value));
    }

    @Override // com.jiuqi.util.IniFile
    public void writeLong(String section, String ident, Long value) {
        writeString(section, ident, value == null ? JqLib.SQL_FALSE : value.toString());
    }

    @Override // com.jiuqi.util.IniFile
    public void writelong(String section, String ident, long value) {
        writeString(section, ident, Long.toString(value));
    }

    @Override // com.jiuqi.util.IniFile
    public void writeDouble(String section, String ident, Double value) {
        writeString(section, ident, value == null ? JqLib.SQL_FALSE : value.toString());
    }

    @Override // com.jiuqi.util.IniFile
    public void writedouble(String section, String ident, double value) {
        writeString(section, ident, Double.toString(value));
    }

    @Override // com.jiuqi.util.IniFile
    public void writeFloat(String section, String ident, Float value) {
        writeString(section, ident, value == null ? JqLib.SQL_FALSE : value.toString());
    }

    @Override // com.jiuqi.util.IniFile
    public void writefloat(String section, String ident, float value) {
        writeString(section, ident, Float.toString(value));
    }

    @Override // com.jiuqi.util.IniFile
    public void writeBoolean(String section, String ident, Boolean value) {
        writeString(section, ident, value == null ? JqLib.SQL_FALSE : value.booleanValue() ? JqLib.SQL_TRUE : JqLib.SQL_FALSE);
    }

    @Override // com.jiuqi.util.IniFile
    public void writeboolean(String section, String ident, boolean value) {
        writeBoolean(section, ident, new Boolean(value));
    }

    @Override // com.jiuqi.util.IniFile
    public void writeBytes(String section, String ident, byte[] value) {
        String s = value == null ? "" : new String(Base64.byteArrayToBase64(value));
        writeString(section, ident, s);
    }

    @Override // com.jiuqi.util.IniFile
    public Integer readInteger(String section, String ident, Integer defvalue) {
        String s = readString(section, ident, "");
        if (s == null || s.equals("")) {
            return defvalue;
        }
        return new Integer(s);
    }

    @Override // com.jiuqi.util.IniFile
    public int readint(String section, String ident, int defvalue) {
        return readInteger(section, ident, new Integer(defvalue)).intValue();
    }

    @Override // com.jiuqi.util.IniFile
    public Long readLong(String section, String ident, Long defvalue) {
        String s = readString(section, ident, "");
        if (s == null || s.equals("")) {
            return defvalue;
        }
        return new Long(s);
    }

    @Override // com.jiuqi.util.IniFile
    public long readlong(String section, String ident, long defvalue) {
        return readLong(section, ident, new Long(defvalue)).longValue();
    }

    @Override // com.jiuqi.util.IniFile
    public Double readDouble(String section, String ident, Double defvalue) {
        String s = readString(section, ident, "");
        if (s == null || s.equals("")) {
            return defvalue;
        }
        return new Double(s);
    }

    @Override // com.jiuqi.util.IniFile
    public double readdouble(String section, String ident, double defvalue) {
        return readDouble(section, ident, new Double(defvalue)).doubleValue();
    }

    @Override // com.jiuqi.util.IniFile
    public Boolean readBoolean(String section, String ident, Boolean defvalue) {
        return new Boolean(readboolean(section, ident, defvalue == null ? false : defvalue.booleanValue()));
    }

    @Override // com.jiuqi.util.IniFile
    public boolean readboolean(String section, String ident, boolean defvalue) {
        String s = readString(section, ident, "");
        return (s == null || s.equals("")) ? defvalue : !s.equals(JqLib.SQL_FALSE);
    }

    @Override // com.jiuqi.util.IniFile
    public byte[] readBytes(String section, String ident, byte[] defvalue) {
        String s = readString(section, ident, "");
        return Base64.base64ToByteArray(s);
    }

    @Override // com.jiuqi.util.IniFile
    public byte[] getBytes() {
        ByteArrayOutputStream stream = new ByteArrayOutputStream();
        saveToStream(stream);
        return stream.toByteArray();
    }

    @Override // com.jiuqi.util.IniFile
    public void setBytes(byte[] value) {
        ByteArrayInputStream stream = new ByteArrayInputStream(value);
        loadFromStream(stream);
    }
}
